@@ -11,7 +11,7 @@ use Exporter qw(import);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-01-17'; # DATE
 our $DIST = 'Complete-Util'; # DIST
-our $VERSION = '0.613'; # VERSION
+our $VERSION = '0.614'; # VERSION
 
 our @EXPORT_OK = qw(
                        hashify_answer
@@ -735,7 +735,8 @@ sub complete_comma_sep {
     {
         last unless @$cae_res == 1;
         last if @$remaining_elems <= 1;
-        $cae_res = [{word=>"$cae_res->[0]$sep", is_partial=>1}];
+        $cae_res = [{word=>$cae_res->[0]}] unless ref $cae_res->[0] eq 'HASH';
+        $cae_res = [{word=>"$cae_res->[0]{word}$sep", (defined $cae_res->[0]{summary} ? (summary=>$cae_res->[0]{summary}) : ()), is_partial=>1}];
     }
     $cae_res;
 }
@@ -936,7 +937,7 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.613 of Complete::Util (from Perl distribution Complete-Util), released on 2023-01-17.
+This document describes version 0.614 of Complete::Util (from Perl distribution Complete-Util), released on 2023-01-17.
 
 =head1 DESCRIPTION
 
